package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.UserFootprintMapper;
import com.ruoyi.system.domain.UserFootprint;
import com.ruoyi.system.service.IUserFootprintService;

/**
 * footprintService业务层处理
 * 
 * @author ruoyi
 * @date 2023-06-16
 */
@Service
public class UserFootprintServiceImpl extends ServiceImpl<BaseMapper<UserFootprint>,UserFootprint> implements IUserFootprintService
{
    @Autowired
    private UserFootprintMapper userFootprintMapper;

    /**
     * 查询footprint
     * 
     * @param id footprint主键
     * @return footprint
     */
    @Override
    public UserFootprint selectUserFootprintById(Long id)
    {
        return userFootprintMapper.selectUserFootprintById(id);
    }

    /**
     * 查询footprint列表
     * 
     * @param userFootprint footprint
     * @return footprint
     */
    @Override
    public List<UserFootprint> selectUserFootprintList(UserFootprint userFootprint)
    {
        return userFootprintMapper.selectUserFootprintList(userFootprint);
    }

    /**
     * 新增footprint
     * 
     * @param userFootprint footprint
     * @return 结果
     */
    @Override
    public int insertUserFootprint(UserFootprint userFootprint)
    {
        return userFootprintMapper.insertUserFootprint(userFootprint);
    }

    /**
     * 修改footprint
     * 
     * @param userFootprint footprint
     * @return 结果
     */
    @Override
    public int updateUserFootprint(UserFootprint userFootprint)
    {
        return userFootprintMapper.updateUserFootprint(userFootprint);
    }

    /**
     * 批量删除footprint
     * 
     * @param ids 需要删除的footprint主键
     * @return 结果
     */
    @Override
    public int deleteUserFootprintByIds(Long[] ids)
    {
        return userFootprintMapper.deleteUserFootprintByIds(ids);
    }

    /**
     * 删除footprint信息
     * 
     * @param id footprint主键
     * @return 结果
     */
    @Override
    public int deleteUserFootprintById(Long id)
    {
        return userFootprintMapper.deleteUserFootprintById(id);
    }
}
